@@ -11,7 +11,7 @@ class EmbedEntry(EntryBlock):
             'type': 'embed',
             'value': {
                 'embed': {
-                    "link": self.mocker.URL_EMBED,
+                    "link": self.URL_EMBED,
                     'size': size_media
                 }
             }
