@@ -11,7 +11,7 @@ class FormEntry(EntryBlock):
     pass
 
     def mock(self, *args, **kwargs):
-        form = self.mocker.get_form('big')
+        form = self.get_form('big')
         self.mock_data.update({
             'type': 'form',
             'value': {
