@@ -38,6 +38,7 @@ AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
+SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
 
 
 #  Models
@@ -125,6 +126,7 @@ class AGenericPage(Page):
         ('articles', ArticlesEntry()),
         ('embed', EmbedEntry()),
         ('social_share', SocialShare()),
+        ('social_links', SocialLinks()),
         ('table', TableEntry()),
         ('accordion', AccordionEntry()),
         ('numbers', NumbersEntry()),
