@@ -99,7 +99,7 @@ class AMPStyles(template.Node):
             href = tree.get('href')
             request = context['request']
             http = 'https://' if request.is_secure() else 'http://'
-            host = request.get_host()
+            host = request.site.hostname
             if host == 'localhost':
                 host += ':8080'
             url = http + host + href
